@@ -1,5 +1,5 @@
 /* ANSI-C code produced by gperf version 3.2 */
-/* Command-line: gperf -m 10 ./unictype/combiningclass_byname.gperf  */
+/* Command-line: gperf -m 10 unictype/combiningclass_byname.gperf  */
 /* Computed positions: -k'1,6,$' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -29,7 +29,7 @@
 #error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
-#line 25 "./unictype/combiningclass_byname.gperf"
+#line 25 "unictype/combiningclass_byname.gperf"
 struct named_combining_class { int name; int combining_class; };
 
 #define TOTAL_KEYWORDS 53
@@ -259,119 +259,119 @@ static const struct combining_class_stringpool_t combining_class_stringpool_cont
 static const struct named_combining_class combining_class_names[] =
   {
     {-1}, {-1}, {-1},
-#line 47 "./unictype/combiningclass_byname.gperf"
+#line 47 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str3, UC_CCC_B},
     {-1},
-#line 38 "./unictype/combiningclass_byname.gperf"
+#line 38 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str5, UC_CCC_OV},
     {-1}, {-1},
-#line 43 "./unictype/combiningclass_byname.gperf"
+#line 43 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str8, UC_CCC_ATB},
-#line 52 "./unictype/combiningclass_byname.gperf"
+#line 52 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str9, UC_CCC_A},
-#line 81 "./unictype/combiningclass_byname.gperf"
+#line 81 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str10, UC_CCC_A},
-#line 44 "./unictype/combiningclass_byname.gperf"
+#line 44 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str11, UC_CCC_ATA},
-#line 48 "./unictype/combiningclass_byname.gperf"
+#line 48 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str12, UC_CCC_BR},
-#line 41 "./unictype/combiningclass_byname.gperf"
+#line 41 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str13, UC_CCC_VR},
-#line 56 "./unictype/combiningclass_byname.gperf"
+#line 56 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str14, UC_CCC_IS},
-#line 53 "./unictype/combiningclass_byname.gperf"
+#line 53 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str15, UC_CCC_AR},
-#line 63 "./unictype/combiningclass_byname.gperf"
+#line 63 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str16, UC_CCC_VR},
-#line 45 "./unictype/combiningclass_byname.gperf"
+#line 45 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str17, UC_CCC_ATAR},
-#line 46 "./unictype/combiningclass_byname.gperf"
+#line 46 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str18, UC_CCC_BL},
-#line 50 "./unictype/combiningclass_byname.gperf"
+#line 50 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str19, UC_CCC_R},
-#line 60 "./unictype/combiningclass_byname.gperf"
+#line 60 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str20, UC_CCC_NK},
-#line 51 "./unictype/combiningclass_byname.gperf"
+#line 51 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str21, UC_CCC_AL},
-#line 37 "./unictype/combiningclass_byname.gperf"
+#line 37 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str22, UC_CCC_NR},
-#line 42 "./unictype/combiningclass_byname.gperf"
+#line 42 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str23, UC_CCC_ATBL},
-#line 78 "./unictype/combiningclass_byname.gperf"
+#line 78 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str24, UC_CCC_R},
-#line 59 "./unictype/combiningclass_byname.gperf"
+#line 59 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str25, UC_CCC_OV},
-#line 69 "./unictype/combiningclass_byname.gperf"
+#line 69 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str26, UC_CCC_ATA},
-#line 68 "./unictype/combiningclass_byname.gperf"
+#line 68 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str27, UC_CCC_ATA},
-#line 74 "./unictype/combiningclass_byname.gperf"
+#line 74 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str28, UC_CCC_B},
-#line 77 "./unictype/combiningclass_byname.gperf"
+#line 77 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str29, UC_CCC_L},
-#line 76 "./unictype/combiningclass_byname.gperf"
+#line 76 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str30, UC_CCC_BR},
-#line 49 "./unictype/combiningclass_byname.gperf"
+#line 49 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str31, UC_CCC_L},
-#line 89 "./unictype/combiningclass_byname.gperf"
+#line 89 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str32, UC_CCC_IS},
-#line 83 "./unictype/combiningclass_byname.gperf"
+#line 83 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str33, UC_CCC_AR},
-#line 54 "./unictype/combiningclass_byname.gperf"
+#line 54 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str34, UC_CCC_DB},
-#line 73 "./unictype/combiningclass_byname.gperf"
+#line 73 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str35, UC_CCC_BL},
-#line 88 "./unictype/combiningclass_byname.gperf"
+#line 88 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str36, UC_CCC_IS},
-#line 55 "./unictype/combiningclass_byname.gperf"
+#line 55 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str37, UC_CCC_DA},
-#line 80 "./unictype/combiningclass_byname.gperf"
+#line 80 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str38, UC_CCC_AL},
-#line 65 "./unictype/combiningclass_byname.gperf"
+#line 65 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str39, UC_CCC_ATBL},
-#line 71 "./unictype/combiningclass_byname.gperf"
+#line 71 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str40, UC_CCC_ATAR},
-#line 64 "./unictype/combiningclass_byname.gperf"
+#line 64 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str41, UC_CCC_ATBL},
-#line 70 "./unictype/combiningclass_byname.gperf"
+#line 70 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str42, UC_CCC_ATAR},
     {-1},
-#line 87 "./unictype/combiningclass_byname.gperf"
+#line 87 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str44, UC_CCC_DA},
-#line 86 "./unictype/combiningclass_byname.gperf"
+#line 86 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str45, UC_CCC_DA},
     {-1},
-#line 67 "./unictype/combiningclass_byname.gperf"
+#line 67 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str47, UC_CCC_ATB},
-#line 66 "./unictype/combiningclass_byname.gperf"
+#line 66 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str48, UC_CCC_ATB},
-#line 72 "./unictype/combiningclass_byname.gperf"
+#line 72 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str49, UC_CCC_BL},
-#line 75 "./unictype/combiningclass_byname.gperf"
+#line 75 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str50, UC_CCC_BR},
-#line 40 "./unictype/combiningclass_byname.gperf"
+#line 40 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str51, UC_CCC_KV},
-#line 79 "./unictype/combiningclass_byname.gperf"
+#line 79 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str52, UC_CCC_AL},
-#line 82 "./unictype/combiningclass_byname.gperf"
+#line 82 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str53, UC_CCC_AR},
     {-1},
-#line 58 "./unictype/combiningclass_byname.gperf"
+#line 58 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str55, UC_CCC_NR},
-#line 57 "./unictype/combiningclass_byname.gperf"
+#line 57 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str56, UC_CCC_NR},
     {-1}, {-1}, {-1},
-#line 39 "./unictype/combiningclass_byname.gperf"
+#line 39 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str60, UC_CCC_NK},
-#line 62 "./unictype/combiningclass_byname.gperf"
+#line 62 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str61, UC_CCC_KV},
     {-1},
-#line 61 "./unictype/combiningclass_byname.gperf"
+#line 61 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str63, UC_CCC_KV},
     {-1},
-#line 85 "./unictype/combiningclass_byname.gperf"
+#line 85 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str65, UC_CCC_DB},
-#line 84 "./unictype/combiningclass_byname.gperf"
+#line 84 "unictype/combiningclass_byname.gperf"
     {(int)(size_t)&((struct combining_class_stringpool_t *)0)->combining_class_stringpool_str66, UC_CCC_DB}
   };
 
