@@ -1,12 +1,11 @@
 /* Previous grapheme cluster function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
-   Written by Ben Pfaff <blp@cs.stanford.edu>, 2010.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This file is free software.
    It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
    You can redistribute it and/or modify it under either
      - the terms of the GNU Lesser General Public License as published
-       by the Free Software Foundation; either version 3, or (at your
+       by the Free Software Foundation, either version 3, or (at your
        option) any later version, or
      - the terms of the GNU General Public License as published by the
        Free Software Foundation; either version 2, or (at your option)
@@ -23,40 +22,20 @@
    License and of the GNU General Public License along with this
    program.  If not, see <https://www.gnu.org/licenses/>.  */
 
+/* Written by Bruno Haible <bruno@clisp.org>, 2025.  */
+
+/* Don't use the const-improved function macros in this compilation unit.  */
+#define _LIBUNISTRING_NO_CONST_GENERICS
+
 #include <config.h>
 
 /* Specification.  */
 #include "unigbrk.h"
 
+#include "unictype.h"
 #include "unistr.h"
 
-const uint16_t *
-u16_grapheme_prev (const uint16_t *s, const uint16_t *start)
-{
-  ucs4_t next;
-
-  if (s == start)
-    return NULL;
-
-  s = u16_prev (&next, s, start);
-  while (s != start)
-    {
-      const uint16_t *prev_s;
-      ucs4_t prev;
-
-      prev_s = u16_prev (&prev, s, start);
-      if (prev_s == NULL)
-        {
-          /* Ill-formed UTF-16 encoding. */
-          return start;
-        }
-
-      if (uc_is_grapheme_break (prev, next))
-        break;
-
-      s = prev_s;
-      next = prev;
-    }
-
-  return s;
-}
+#define FUNC u16_grapheme_prev
+#define UNIT uint16_t
+#define U_PREV u16_prev
+#include "u-grapheme-prev.h"
