@@ -1,27 +1,26 @@
 /* Elementary Unicode string functions.
-   Copyright (C) 2002, 2005-2007, 2009-2018 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2005-2007, 2009-2025 Free Software Foundation, Inc.
 
-   This program is free software: you can redistribute it and/or
-   modify it under the terms of either:
+   This file is free software.
+   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
+   You can redistribute it and/or modify it under either
+     - the terms of the GNU Lesser General Public License as published
+       by the Free Software Foundation, either version 3, or (at your
+       option) any later version, or
+     - the terms of the GNU General Public License as published by the
+       Free Software Foundation; either version 2, or (at your option)
+       any later version, or
+     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".
 
-     * the GNU Lesser General Public License as published by the Free
-       Software Foundation; either version 3 of the License, or (at your
-       option) any later version.
-
-   or
-
-     * the GNU General Public License as published by the Free
-       Software Foundation; either version 2 of the License, or (at your
-       option) any later version.
-
-   or both in parallel, as here.
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
+   Lesser General Public License and the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public
+   License and of the GNU General Public License along with this
+   program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifndef _UNISTDIO_H
 #define _UNISTDIO_H
@@ -70,28 +69,28 @@ extern "C" {
 
 /* ASCII format string, result in locale dependent encoded 'char *'.  */
 extern int
-       ulc_sprintf (char *buf,
+       ulc_sprintf (char *_UC_RESTRICT buf,
                     const char *format, ...);
 extern int
-       ulc_snprintf (char *buf, size_t size,
+       ulc_snprintf (char *_UC_RESTRICT buf, size_t size,
                      const char *format, ...);
 extern int
        ulc_asprintf (char **resultp,
                      const char *format, ...);
 extern char *
-       ulc_asnprintf (char *resultbuf, size_t *lengthp,
+       ulc_asnprintf (char *_UC_RESTRICT resultbuf, size_t *lengthp,
                       const char *format, ...);
 extern int
-       ulc_vsprintf (char *buf,
+       ulc_vsprintf (char *_UC_RESTRICT buf,
                      const char *format, va_list ap);
 extern int
-       ulc_vsnprintf (char *buf, size_t size,
+       ulc_vsnprintf (char *_UC_RESTRICT buf, size_t size,
                       const char *format, va_list ap);
 extern int
        ulc_vasprintf (char **resultp,
                       const char *format, va_list ap);
 extern char *
-       ulc_vasnprintf (char *resultbuf, size_t *lengthp,
+       ulc_vasnprintf (char *_UC_RESTRICT resultbuf, size_t *lengthp,
                        const char *format, va_list ap);
 
 /* ASCII format string, result in UTF-8 format.  */
@@ -122,28 +121,28 @@ extern uint8_t *
 
 /* UTF-8 format string, result in UTF-8 format.  */
 extern int
-       u8_u8_sprintf (uint8_t *buf,
+       u8_u8_sprintf (uint8_t *_UC_RESTRICT buf,
                       const uint8_t *format, ...);
 extern int
-       u8_u8_snprintf (uint8_t *buf, size_t size,
+       u8_u8_snprintf (uint8_t *_UC_RESTRICT buf, size_t size,
                        const uint8_t *format, ...);
 extern int
        u8_u8_asprintf (uint8_t **resultp,
                        const uint8_t *format, ...);
 extern uint8_t *
-       u8_u8_asnprintf (uint8_t *resultbuf, size_t *lengthp,
+       u8_u8_asnprintf (uint8_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                         const uint8_t *format, ...);
 extern int
-       u8_u8_vsprintf (uint8_t *buf,
+       u8_u8_vsprintf (uint8_t *_UC_RESTRICT buf,
                        const uint8_t *format, va_list ap);
 extern int
-       u8_u8_vsnprintf (uint8_t *buf, size_t size,
+       u8_u8_vsnprintf (uint8_t *_UC_RESTRICT buf, size_t size,
                         const uint8_t *format, va_list ap);
 extern int
        u8_u8_vasprintf (uint8_t **resultp,
                         const uint8_t *format, va_list ap);
 extern uint8_t *
-       u8_u8_vasnprintf (uint8_t *resultbuf, size_t *lengthp,
+       u8_u8_vasnprintf (uint8_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                          const uint8_t *format, va_list ap);
 
 /* ASCII format string, result in UTF-16 format.  */
@@ -174,28 +173,28 @@ extern uint16_t *
 
 /* UTF-16 format string, result in UTF-16 format.  */
 extern int
-       u16_u16_sprintf (uint16_t *buf,
+       u16_u16_sprintf (uint16_t *_UC_RESTRICT buf,
                         const uint16_t *format, ...);
 extern int
-       u16_u16_snprintf (uint16_t *buf, size_t size,
+       u16_u16_snprintf (uint16_t *_UC_RESTRICT buf, size_t size,
                          const uint16_t *format, ...);
 extern int
        u16_u16_asprintf (uint16_t **resultp,
                          const uint16_t *format, ...);
 extern uint16_t *
-       u16_u16_asnprintf (uint16_t *resultbuf, size_t *lengthp,
+       u16_u16_asnprintf (uint16_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                           const uint16_t *format, ...);
 extern int
-       u16_u16_vsprintf (uint16_t *buf,
+       u16_u16_vsprintf (uint16_t *_UC_RESTRICT buf,
                          const uint16_t *format, va_list ap);
 extern int
-       u16_u16_vsnprintf (uint16_t *buf, size_t size,
+       u16_u16_vsnprintf (uint16_t *_UC_RESTRICT buf, size_t size,
                           const uint16_t *format, va_list ap);
 extern int
        u16_u16_vasprintf (uint16_t **resultp,
                           const uint16_t *format, va_list ap);
 extern uint16_t *
-       u16_u16_vasnprintf (uint16_t *resultbuf, size_t *lengthp,
+       u16_u16_vasnprintf (uint16_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                            const uint16_t *format, va_list ap);
 
 /* ASCII format string, result in UTF-32 format.  */
@@ -226,28 +225,28 @@ extern uint32_t *
 
 /* UTF-32 format string, result in UTF-32 format.  */
 extern int
-       u32_u32_sprintf (uint32_t *buf,
+       u32_u32_sprintf (uint32_t *_UC_RESTRICT buf,
                         const uint32_t *format, ...);
 extern int
-       u32_u32_snprintf (uint32_t *buf, size_t size,
+       u32_u32_snprintf (uint32_t *_UC_RESTRICT buf, size_t size,
                          const uint32_t *format, ...);
 extern int
        u32_u32_asprintf (uint32_t **resultp,
                          const uint32_t *format, ...);
 extern uint32_t *
-       u32_u32_asnprintf (uint32_t *resultbuf, size_t *lengthp,
+       u32_u32_asnprintf (uint32_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                           const uint32_t *format, ...);
 extern int
-       u32_u32_vsprintf (uint32_t *buf,
+       u32_u32_vsprintf (uint32_t *_UC_RESTRICT buf,
                          const uint32_t *format, va_list ap);
 extern int
-       u32_u32_vsnprintf (uint32_t *buf, size_t size,
+       u32_u32_vsnprintf (uint32_t *_UC_RESTRICT buf, size_t size,
                           const uint32_t *format, va_list ap);
 extern int
        u32_u32_vasprintf (uint32_t **resultp,
                           const uint32_t *format, va_list ap);
 extern uint32_t *
-       u32_u32_vasnprintf (uint32_t *resultbuf, size_t *lengthp,
+       u32_u32_vasnprintf (uint32_t *_UC_RESTRICT resultbuf, size_t *lengthp,
                            const uint32_t *format, va_list ap);
 
 /* ASCII format string, output to FILE in locale dependent encoding.  */
