@@ -1,5 +1,5 @@
 /* Test of splitting a 'long double' into fraction and mantissa.
-   Copyright (C) 2007-2024 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,15 +25,10 @@
 #include "fpucw.h"
 #include "macros.h"
 
-/* On MIPS IRIX machines, LDBL_MIN_EXP is -1021, but the smallest reliable
-   exponent for 'long double' is -964.  Similarly, on PowerPC machines,
-   LDBL_MIN_EXP is -1021, but the smallest reliable exponent for 'long double'
-   is -968.  For exponents below that, the precision may be truncated to the
-   precision used for 'double'.  */
-#ifdef __sgi
-# define MIN_NORMAL_EXP (LDBL_MIN_EXP + 57)
-# define MIN_SUBNORMAL_EXP MIN_NORMAL_EXP
-#elif defined __ppc || defined __ppc__ || defined __powerpc || defined __powerpc__
+/* On PowerPC machines, LDBL_MIN_EXP is -1021, but the smallest reliable
+   exponent for 'long double' is -968.  For exponents below that, the precision
+   may be truncated to the precision used for 'double'.  */
+#if defined __ppc || defined __ppc__ || defined __powerpc || defined __powerpc__
 # define MIN_NORMAL_EXP (LDBL_MIN_EXP + 53)
 # define MIN_SUBNORMAL_EXP MIN_NORMAL_EXP
 #else
