@@ -1,5 +1,5 @@
 /* Grapheme cluster breaks test.
-   Copyright (C) 2010-2024 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
@@ -107,7 +107,7 @@ main (void)
 
   /* Emoji modifier / ZWJ sequence. */
   test_u16_grapheme_breaks ("#____",
-                            0x2605, 0x0305, 0x0347, 0x200D, 0x2600,
+                            0x2B50, 0x0305, 0x0347, 0x200D, 0x2600,
                             -1);
 
   /* Regional indicators. */
