@@ -1,5 +1,5 @@
 /* Test of u32_mbtoucr() function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -79,5 +79,5 @@ main ()
     ASSERT (uc == 0xFFFD);
   }
 
-  return 0;
+  return test_exit_status;
 }
